/* $Id: ssh_global.h,v 1.5 2000/09/22 01:19:02 andrew Exp $ */

/*
 * Copyright 1999 RedBack Networks, Incorporated.
 * All rights reserved.
 *
 * This software is not in the public domain.  It is distributed 
 * under the terms of the license in the file LICENSE in the
 * same directory as this file.  If you have received a copy of this
 * software without the LICENSE file (which means that whoever gave
 * you this software violated its license) you may obtain a copy from
 * http://www.panix.com/~tls/LICENSE.txt
 */


#ifndef _SSH_GLOBAL_H
#define _SSH_GLOBAL_H

struct ssh_cipher;

extern int exitflag;
extern int nodaemon;
extern ssh_context_t g_context;
extern struct ssh_cipher g_cipher;

#endif _SSH_GLOBAL_H
